waterObsL     = {0,    1000,  2000, 3000, 4000, 5000, 6000, 7000, 8000}   -- KAF
surfaceObsL   = {0,    24.7,  35.3, 48.6, 54.3, 57.2, 61.6, 66.0, 69.9}   -- KA
elevationObsL = { 6224, 6335, 6369, 6392, 6412, 6430, 6447, 6463, 6477}    -- feet
-----------
-- Table 4.2 - in Ford's book
function evapRateFactor (specificGravity)

 	a = -1.4208080808073591E+00;
 	b = 6.6409259259240558E+00;
 	c = -5.5515151515135548E+00;
 	d = 1.3265993265988749E+00;

 	local evapRateReductionFactor = a + b*specificGravity+ c*specificGravity^2 + d*specificGravity^3 

	return evapRateReductionFactor
end
------------- using the the specific Gravity to estimate the Evaporation rate multiplier
function calcEvaporation (monoLake)

	local massFreshwater = monoLake.stocks.waterInTheLake * monoLake.params.massFreshWaterPerKAF

	local specificGravity = (massFreshwater + monoLake.params.dissolvedSolids) / massFreshwater

	local evaporationRate = evapRateFactor (specificGravity) * monoLake.params.freshWaterEvaporationRate

	evaporation   = monoLake.variables.surfaceArea * evaporationRate

	return evaporation
end

---------------- Table 4.1 in Ford's book  (surfaceWater as a function of volume of water in the lake)

function estimateSurfaceArea (water)

	a = 8.1414177963836043E-01
	b = 2.5222522481624796E-02
	c = -3.8848123899271551E-06
	d = 2.2744107985861461E-10

	local surfaceArea = a + b*water + c*water^2 + d*water^3 

	return surfaceArea

end
---------- Table 4.1 in Ford's book  (elevation as a function of volume of water in the lake)
function estimateElevation (water)

	a = 6.2344545468507940E+03
	b = 9.6353533955755757E-02
	c = -1.6848484772520475E-05
	d = 1.0858585974826696E-09

	local elevation = a + b*water + c*water^2 + d*water^3 

	return elevation
end
-------------------

function changes (monoLake)
    
    monoLake.variables.surfaceArea = estimateSurfaceArea (monoLake.stocks.waterInTheLake)
	monoLake.outcomes.elevation    = estimateElevation (monoLake.stocks.waterInTheLake) 

	monoLake.flows.precipitation    = monoLake.variables.surfaceArea * monoLake.params.precipitationRate

	monoLake.flows.evaporation      = calcEvaporation (monoLake)

	local otherOut =   monoLake.flows.evaporationGrantLake  
	                 + monoLake.flows.evapotranspirationVeg
	                 + monoLake.flows.groundwaterExport
	                 + monoLake.flows.exposedLakeBottomEvap

	local otherIn  =   monoLake.flows.otherSierraRunoff
				     + monoLake.flows.nonSierraRunoff
				     + monoLake.flows.netSurfacePrecip
				     + monoLake.flows.diversionInflows

	monoLake.stocks.waterInTheLake = monoLake.stocks.waterInTheLake 
		+ monoLake.flows.precipitation
		+ monoLake.flows.sierraRunoff    -- water from the mountains
		+ otherIn
		- monoLake.flows.evaporation
		- otherOut
		- monoLake.policy.waterExport

	if (monoLake.stocks.waterInTheLake <= 0 ) then
		monoLake.stocks.waterInTheLake = 0
	end
end

---------

monoLake = {
		policy        = { waterExport = 0},
		outcomes      = { elevation = 0 },
		stocks        = { waterInTheLake = 2228 },
		variables     = { surfaceArea      = 0  },  
		flows         = { -- main natural inflow
						  sierraRunoff          = 150, 
						  -- main natural outflows 
						  evaporation           =   0,  
						  precipitation         =   0, 
						  -- other outflows
						  evaporationGrantLake  =   1.3,
						  evapotranspirationVeg =  13,
						  exposedLakeBottomEvap =  12,
						  groundwaterExport     =   7.3,
						  -- other inflows
						  otherSierraRunoff     =  17,
						  nonSierraRunoff       =  20,
						  netSurfacePrecip      =   9,
						  diversionInflows      =   1.6
						},
		params        = { precipitationRate = 0.667, 
	                  	  freshWaterEvaporationRate = 3.75, 
	                  	  massFreshWaterPerKAF = 1.359, 
	                  	  dissolvedSolids = 230
	                  	}
}
